const express = require("express");
const router = express.Router();
const multer = require("multer");
const db_con = require("../connection");

const storage = multer.diskStorage({
  destination: function (req, file, cb) {
    cb(null, "uploads/");
  },
  filename: function (req, file, cb) {
    cb(null, Date.now() + file.originalname);
  },
});

let upload = multer({
  storage: storage,
});

router.get("/", (req, res, next) => {
  res.send("Hellow world");
  console.log("Tour Added");
});

// add testimonial
router.post("/addTestimonial", (req, res) => {
  const testBody = req.body;
  let query =
    "INSERT INTO all_testimonial (`test_id`,`test_content`,`test_heading`,`test_img`) VALUES (?,?,?,?)";

  db_con.query(
    query,
    [
      testBody.test_id,
      testBody.test_content,
      testBody.test_heading,
      testBody.test_img,
    ],
    (error, results, fields) => {
      if (error) {
        console.log(error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        console.log("Testimonial Added Successfully");
        res.send({
          code: 200,
          message: "Testimonial Added Successfully",
        });
      }
    }
  );
});

// update testimonial

router.post("/updateTestimonial", (req, res) => {
  const testBody = req.body.testBody;
  let query = `UPDATE all_testimonial SET ? WHERE test_id= ?`;
  let body = {};

  db_con.query(
    query,
    [req.body.testBody, req.body.test_id],
    (error, results, fields) => {
      if (error) {
        console.log("error ocurred", error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Updated Successfully",
        });
      }
    }
  );
});

// get testimonial
router.get("/getAllTestimonial", (req, res) => {
  query = "SELECT * FROM all_testimonial";
  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

// delete testimonial
router.post("/deleteTestimonial", (req, res) => {
  const body = req.body;
  let query = `DELETE FROM all_testimonial WHERE test_id = ?`;
  db_con.query(query, [body.test_id], (error, results, fields) => {
    if (error) {
      console.log("error ocurred", error);
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      console.log("Resultats: ", results);
      res.send({
        code: 200,
        message: "Deleted Successfully",
      });
    }
  });
});

// add service
router.post("/addNewService", (req, res) => {
  const testBody = req.body;
  let query =
    "INSERT INTO service_content (`service_id`,`service_slNo`,`service_heading`,`service_img`,`service_content`) VALUES (?,?,?,?,?)";

  db_con.query(
    query,
    [
      testBody.service_id,
      testBody.service_slNo,
      testBody.service_heading,
      testBody.service_img,
      testBody.service_content,
    ],
    (error, results, fields) => {
      if (error) {
        console.log(error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        console.log("Service Added Successfully");
        res.send({
          code: 200,
          message: "Service Added Successfully",
        });
      }
    }
  );
});

// update service

router.post("/updateService", (req, res) => {
  const serviceBody = req.body;
  let query = `UPDATE service_content SET ? WHERE service_id= ?`;
  db_con.query(
    query,
    [serviceBody, serviceBody.service_id],
    (error, results, fields) => {
      if (error) {
        console.log("error ocurred", error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Updated Successfully",
        });
      }
    }
  );
});

// get service
router.get("/getAllService", (req, res) => {
  query = "SELECT * FROM service_content";
  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

// delete service
router.post("/deleteService", (req, res) => {
  const body = req.body;
  let query = `DELETE FROM service_content WHERE service_id = ?`;
  db_con.query(query, [body.service_id], (error, results, fields) => {
    if (error) {
      console.log("error ocurred", error);
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      console.log("Resultats: ", results);
      res.send({
        code: 200,
        message: "Deleted Successfully",
      });
    }
  });
});

// add banner
router.post("/addBanner", (req, res) => {
  const bannerBody = req.body;
  let query =
    "INSERT INTO all_banner (`banner_id`,`banner_content`,`banner_heading`,`banner_img`) VALUES (?,?,?,?)";

  db_con.query(
    query,
    [
      bannerBody.banner_id,
      bannerBody.banner_content,
      bannerBody.banner_heading,
      bannerBody.banner_img,
    ],
    (error, results, fields) => {
      if (error) {
        console.log(error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Banner Added Successfully",
        });
      }
    }
  );
});

// update banner

router.post("/updateBanner", (req, res) => {
  let query = `UPDATE all_banner SET ? WHERE banner_id= ?`;
  let body = {};

  db_con.query(
    query,
    [req.body.bannerBody, req.body.banner_id],
    (error, results, fields) => {
      if (error) {
        console.log("error ocurred", error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Updated Successfully",
        });
      }
    }
  );
});

// get banner
router.get("/getAllBanner", (req, res) => {
  query = "SELECT * FROM all_banner";
  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

// delete banner
router.post("/deleteBanner", (req, res) => {
  const body = req.body;
  let query = `DELETE FROM all_banner WHERE banner_id = ?`;
  db_con.query(query, [body.banner_id], (error, results, fields) => {
    if (error) {
      console.log("error ocurred", error);
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      console.log("Resultats: ", results);
      res.send({
        code: 200,
        message: "Deleted Successfully",
      });
    }
  });
});

// add heading and content
router.post("/addNewContentAndHeading", (req, res) => {
  const contentBody = req.body;
  let query =
    "INSERT INTO headings_content (`content_id`,`content_heading`,`content_text`,`content_sub_heading`,`content_type`) VALUES (?,?,?,?,?)";

  db_con.query(
    query,
    [
      contentBody.content_id,
      contentBody.content_heading,
      contentBody.content_text,
      contentBody.content_sub_heading,
      contentBody.content_type,
    ],
    (error, results, fields) => {
      if (error) {
        console.log(error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Content Added Successfully",
        });
      }
    }
  );
});

// update heading and content

router.post("/updateContentAndHeading", (req, res) => {
  let query = `UPDATE headings_content SET ? WHERE content_id= ?`;
  let body = {};

  db_con.query(
    query,
    [req.body, req.body.content_id],
    (error, results, fields) => {
      if (error) {
        console.log("error ocurred", error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Updated Successfully",
        });
      }
    }
  );
});

// get heading and content
router.get("/getAllContentAndHeading", (req, res) => {
  query = "SELECT * FROM headings_content";
  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

// delete heading and content
router.post("/deleteContentAndHeading", (req, res) => {
  const body = req.body;
  let query = `DELETE FROM headings_content WHERE content_id = ?`;
  db_con.query(query, [body.content_id], (error, results, fields) => {
    if (error) {
      console.log("error ocurred", error);
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      console.log("Resultats: ", results);
      res.send({
        code: 200,
        message: "Deleted Successfully",
      });
    }
  });
});

// add gallery data
router.post("/addGallery", (req, res) => {
  const galleryBody = req.body;
  let tableHeader = [];
  console.log(galleryBody);
  tableHeader.push(
    `img_id`,
    `img_name`,
    `img_base_url`,
    `img_size`,
    `img_mimetype`,
    `img_url`,
    `caption`
  );
  let truncate = "TRUNCATE TABLE all_gallery;";
  db_con.query(truncate, (error, results, fields) => {
    if (error) {
      console.log(error);
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      let query = "INSERT INTO all_gallery (" + tableHeader + ") VALUES ?";
      let values = galleryBody.reduce((o, a) => {
        let ini = [];
        ini.push(a.img_id);
        ini.push(a.img_name);
        ini.push(a.img_base_url);
        ini.push(a.img_size);
        ini.push(a.img_mimetype);
        ini.push(a.img_url);
        ini.push(a.caption);
        o.push(ini);
        return o;
      }, []);

      db_con.query(query, [values], (error, results, fields) => {
        if (error) {
          console.log(error);
          res.send({
            code: 400,
            failed: "error request",
          });
        } else {
          res.send({
            code: 200,
            message: "Gallery Added Successfully",
          });
        }
      });
    }
  });
});

// get gallery
router.get("/getAllGallery", (req, res) => {
  query = "SELECT * FROM all_gallery";
  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

// get gallery for home page
router.get("/getGalleryForHome", (req, res) => {
  query = "select * from all_gallery order by img_id desc limit 8;";

  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

// add contact details
router.post("/updateContactDetails", (req, res) => {
  let query = `UPDATE contact_details SET ? WHERE contact_id= ?`;
  console.log(req.body);
  db_con.query(
    query,
    [req.body, req.body.contact_id],
    (error, results, fields) => {
      if (error) {
        console.log("error ocurred", error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        console.log("update");
        res.send({
          code: 200,
          message: "Updated Successfully",
        });
      }
    }
  );
});

// get contact details
router.get("/getContactDetails", (req, res) => {
  query = "SELECT * FROM contact_details";
  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

// add footer details
router.post("/updateFooterDetails", (req, res) => {
  let query = `UPDATE footer_details SET ? WHERE footer_id= ?`;
  db_con.query(
    query,
    [req.body, req.body.footer_id],
    (error, results, fields) => {
      if (error) {
        console.log("error ocurred", error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Updated Successfully",
        });
      }
    }
  );
});

// get footer details
router.get("/getFooterDetails", (req, res) => {
  query = "SELECT * FROM footer_details";
  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

// add settings vendor percentage
router.post("/addPercentageValue", (req, res) => {
  let query = `UPDATE settings SET ? WHERE id= ?`;
  db_con.query(query, [req.body, req.body.id], (error, results, fields) => {
    if (error) {
      console.log("error ocurred", error);
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Updated Successfully",
      });
    }
  });
  // const contentBody = req.body;
  // let query = 'INSERT INTO settings (`vendor_percentage`,`id`) VALUES (?,?)';

  // db_con.query(query, [contentBody.vendor_percentage, contentBody.id], (error, results, fields) => {
  //     if (error) {
  //         console.log(error)
  //         res.send({
  //             "code": 400,
  //             "failed": "error request"
  //         })
  //     } else {
  //         res.send({
  //             "code": 200,
  //             "message": "Content Added Successfully"
  //         });
  //     }
  // });
});

router.post("/updateCurrency", (req, res) => {
  let query = `UPDATE settings SET cur_convertor = ? WHERE id = ?; `;
  const body = req.body;
  db_con.query(
    query,
    [body.cur_convertor, body.id],
    (error, results, fields) => {
      if (error) {
        console.log("error ocurred", error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Updated Successfully",
        });
      }
    }
  );
});

router.post("/updateHomeSection", (req, res) => {
  let query = `UPDATE settings SET page_section = ? WHERE id = ?; `;
  const body = req.body;
  db_con.query(
    query,
    [body.page_section, body.id],
    (error, results, fields) => {
      if (error) {
        console.log("error ocurred", error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Updated Successfully",
        });
      }
    }
  );
});

// get settings vendor percentage
router.get("/getPercentageValue", (req, res) => {
  query = "SELECT * FROM settings";
  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

//about us short wideget
router.post("/addAboutUsShortWidget", (req, res) => {
  let query = `UPDATE pages_other_content SET ? WHERE page_id= ?`;
  db_con.query(
    query,
    [req.body, req.body.page_id],
    (error, results, fields) => {
      if (error) {
        console.log("error ocurred", error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Updated Successfully",
        });
      }
    }
  );

  // const contentBody = req.body;
  // let query = 'INSERT INTO pages_other_content (`page_id`,`page_name`,`page_content_type`,`page_content`,`page_created_date`) VALUES (?,?,?,?,?)';

  // db_con.query(query, [contentBody.page_id, contentBody.page_name, contentBody.page_content_type, contentBody.page_content, contentBody.page_created_date], (error, results, fields) => {
  //     if (error) {
  //         console.log(error)
  //         res.send({
  //             "code": 400,
  //             "failed": "error request"
  //         })
  //     } else {
  //         res.send({
  //             "code": 200,
  //             "message": "Content Added Successfully"
  //         });
  //     }
  // });
});

//about us short wideget
router.get("/getAboutUsShortWidget", (req, res) => {
  query = "SELECT * FROM pages_other_content";
  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

router.post("/addOthersContentAndPages", (req, res) => {
  let query = `UPDATE pages_other_content SET ? WHERE page_id= ?`;
  db_con.query(
    query,
    [req.body, req.body.page_id],
    (error, results, fields) => {
      if (error) {
        console.log("error ocurred", error);
        res.send({
          code: 400,
          failed: "error request",
        });
      } else {
        res.send({
          code: 200,
          message: "Updated Successfully",
        });
      }
    }
  );
});

router.get("/getOthersContentAndPages", (req, res) => {
  query = "SELECT * FROM pages_other_content";
  db_con.query(query, function (error, results, fields) {
    if (error) {
      res.send({
        code: 400,
        failed: "error request",
      });
    } else {
      res.send({
        code: 200,
        message: "Success",
        Payload: results,
      });
    }
  });
});

const id = (length) => {
  let mask = "";
  mask += "0123456789";
  let result = "";
  for (var i = length; i > 0; --i)
    result += mask[Math.round(Math.random() * (mask.length - 1))];
  return result;
};

module.exports = router;
